You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by we...@apache.org on 2006/04/08 16:16:49 UTC

svn commit: r392528 - /incubator/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/HasLabelWithAccessKey.java

Author: weber
Date: Sat Apr  8 07:16:47 2006
New Revision: 392528

URL: http://svn.apache.org/viewcvs?rev=392528&view=rev
Log:
TOBAGO-10 (Combine the attributes label, labelWithAccessKey and accessKey to one attribute label)
Mark as attributes 'labelWithAccessKey' and 'accessKey' as deprecated.

Modified:
    incubator/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/HasLabelWithAccessKey.java

Modified: incubator/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/HasLabelWithAccessKey.java
URL: http://svn.apache.org/viewcvs/incubator/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/HasLabelWithAccessKey.java?rev=392528&r1=392527&r2=392528&view=diff
==============================================================================
--- incubator/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/HasLabelWithAccessKey.java (original)
+++ incubator/tobago/trunk/core/src/main/java/org/apache/myfaces/tobago/taglib/decl/HasLabelWithAccessKey.java Sat Apr  8 07:16:47 2006
@@ -26,17 +26,22 @@
 public interface HasLabelWithAccessKey {
 
   /**
    * Text value to display as label. Overwites 'label'.
    * If text contains an underscore the next character overwrites 'accesskey'.
+   * @deprecated
    */
   @TagAttribute @UIComponentTagAttribute()
+  @Deprecated
   void setLabelWithAccessKey(String key);
 
 
   /**
-   * Character used as accesskey. Overwritten by 'labelWithAccessKey'.
+   * Deprecated! Has not longer any function.
+   * @deprecated
    */
 //  @TagAttribute @UIComponentTagAttribute(type = String.class)
   @TagAttribute @UIComponentTagAttribute(type = { "java.lang.String", "java.lang.Character" })
+  @Deprecated
   void setAccessKey(String key);
 }
@@ -26,17 +26,22 @@
 
   /**
-   * Text value to display as label. Overwites 'label'.
+   * Deprecated! Use 'label' instead.
+   * Text value to display as label.
    * If text contains an underscore the next character overwrites 'accesskey'.